@@ -1,4 +1,4 @@
 from __future__ import absolute_import
 
-from .devices import *
+from .devices import zed, xsens, optitrack, mmodal, emg
 from .utils import *
\ No newline at end of file
